@@ -12,6 +12,7 @@
 #  include "device/bluetoth/blue_w32.h"
 #else
 #  include "device/serial/ser_unx.h"
+#  include "device/bluetoth/bluez.h"
 #endif
 #include "device/irda/irda.h"
 
@@ -23,6 +24,7 @@
 #include "phone/nokia/dct3/n7110.h"
 #include "phone/nokia/dct4s40/n6510.h"
 #include "phone/nokia/nauto.h"
+#include "phone/obex/obexgen.h"
 
 GSM_StateMachine::GSM_StateMachine(FILE *deb_file, char *FileName, bool enable)
 {
@@ -44,7 +46,7 @@ GSM_StateMachine::GSM_StateMachine(FILE *deb_file, char *FileName, bool enable)
 
         Devices->Add(new GSM_Device_Infrared(&Debug));
         Devices->Add(new GSM_Device_Serial(&Debug));
-#ifdef WIN32
+#if defined (WIN32) || defined (BLUEZ)
         Devices->Add(new GSM_Device_Bluetooth(&Debug));
 #endif
 
@@ -56,6 +58,7 @@ GSM_StateMachine::GSM_StateMachine(FILE *deb_file, char *FileName, bool enable)
         Phones->Add(new GSM_Phone_N7110(&Debug,&(Devices->Current),&Protocols,&Phones));
         Phones->Add(new GSM_Phone_N6510(&Debug,&(Devices->Current),&Protocols,&Phones));
         Phones->Add(new GSM_Phone_NAUTO(&Debug,&(Devices->Current),&Protocols,&Phones));
+        Phones->Add(new GSM_Phone_OBEXGEN(&Debug,&(Devices->Current),&Protocols,&Phones));
 }
 
 GSM_StateMachine::~GSM_StateMachine()
@@ -124,10 +127,15 @@ GSM_Error GSM_StateMachine::Open(GSM_GPlusConfig *CFG)
 		if (!strcmp((char *)Prot2.data(),(*proinfo).Protocol)) break;
         }
 
+	if (CFG->Features[0] != 0) {
+		sprintf(Phones->Features,"%s",CFG->Features);
+	}
+
         if (CFG->Phone[0] == 0 && (*proinfo).CanUseDeviceName) {
-		error=Phones->SwitchToDeviceName(DeviceName,(char *)Prot2.data(),CFG->Compatibility);
+		error=Phones->SwitchToDeviceName(DeviceName,(char *)Prot2.data());
+		if (error.Code == GSM_ERR_CONVERTED) error.Code = GSM_ERR_NONE;
 	} else {
-                error=Phones->Switch((char *)Pho2.data(),(char *)Prot2.data(),CFG->Compatibility);
+                error=Phones->Switch((char *)Pho2.data(),(char *)Prot2.data());
 	}
 	if (error.Code != GSM_ERR_NONE) return error;
 
@@ -138,6 +146,11 @@ GSM_Error GSM_StateMachine::Open(GSM_GPlusConfig *CFG)
         error=Phones->Current->GetCodeNameModel(Buff);
         if (error.Code != GSM_ERR_NONE) return error;
 
+	if (Phones->Model == NULL) {
+		error=Phones->SwitchToCodeName((char *)Buff,(char *)Prot2.data());
+	        if (error.Code != GSM_ERR_NONE) return error;
+	}
+
         return GSM_Return_Error(GSM_ERR_NONE);
 }
 
@@ -161,7 +174,7 @@ BOOLEAN GSM_StateMachine::ReadCfgFile(INI_File *File)
 void GSM_StateMachine::ReadCfg(int Set, GSM_GPlusConfig *CFG)
 {
 	INI_File	File;
-	char		buff[40];
+	char		buff[40],buff2[40];
 	wchar_t		*value, x[200];
 	BOOLEAN		read;
 
@@ -195,10 +208,6 @@ void GSM_StateMachine::ReadCfg(int Set, GSM_GPlusConfig *CFG)
 	value = File.GetValue(x,StringToUnicodeReturn("model"));
 	if (value != NULL) sprintf(CFG->Phone,"%s",UnicodeToStringReturn(value));
 
-	CFG->Compatibility[0] = 0;
-	value = File.GetValue(x,StringToUnicodeReturn("compatibility"));
-	if (value != NULL) sprintf(CFG->Compatibility,"%s",UnicodeToStringReturn(value));
-
 	strcpy(CFG->LogLevel,"nothing");
 	value = File.GetValue(x,StringToUnicodeReturn("logformat"));
 	if (value != NULL) sprintf(CFG->LogLevel,"%s",UnicodeToStringReturn(value));
@@ -222,6 +231,17 @@ void GSM_StateMachine::ReadCfg(int Set, GSM_GPlusConfig *CFG)
 	sprintf(CFG->Features,"");
 	value = File.GetValue(x,StringToUnicodeReturn("features"));
 	if (value != NULL) sprintf(CFG->Features,"%s",UnicodeToStringReturn(value));
+
+	sprintf(buff,"GPlusGUI");
+	StringToUnicode(buff,x);
+	sprintf(CFG->Active,"no");
+	value = File.GetValue(x,StringToUnicodeReturn("active"));
+	if (value != NULL) {
+		sprintf(buff2,"%i",Set);
+		if (!strcmp(UnicodeToStringReturn(value),buff2)) {
+			sprintf(CFG->Active,"yes");
+		}
+	}
 }
 
 /**
@@ -230,7 +250,7 @@ void GSM_StateMachine::ReadCfg(int Set, GSM_GPlusConfig *CFG)
 void GSM_StateMachine::SaveCfg(int Set, GSM_GPlusConfig *CFG)
 {
 	INI_File	File;
-	char		buff[40];
+	char		buff[40],buff2[40];
 	wchar_t		x[200], x2[200];	
 	BOOLEAN		read;
 
@@ -252,9 +272,6 @@ void GSM_StateMachine::SaveCfg(int Set, GSM_GPlusConfig *CFG)
 	StringToUnicode("model",x2);
 	File.SetValue(x,x2,StringToUnicodeReturn(CFG->Phone));
 
-	StringToUnicode("compatibility",x2);
-	File.SetValue(x,x2,StringToUnicodeReturn(CFG->Compatibility));
-
 	StringToUnicode("logformat",x2);
 	File.SetValue(x,x2,StringToUnicodeReturn(CFG->LogLevel));
 
@@ -273,6 +290,14 @@ void GSM_StateMachine::SaveCfg(int Set, GSM_GPlusConfig *CFG)
 	StringToUnicode("features",x2);
 	File.SetValue(x,x2,StringToUnicodeReturn(CFG->Features));
 
+	if (!strcmp(CFG->Active,"yes")) {
+		sprintf(buff,"GPlusGUI");
+		StringToUnicode(buff,x);
+		sprintf(buff2,"%i",Set);
+		StringToUnicode("active",x2);
+		File.SetValue(x,x2,StringToUnicodeReturn(buff2));
+	}
+
 	if (read) {
 		File.SaveToDisk(UnicodeToStringReturn(File.Info.ID.data()));
 	} else {
