@@ -13,13 +13,13 @@ typedef struct {
 	char		Device[200];
 	char		Protocol[200];
 	char		Phone[200];
-	char		Compatibility[200];
 	char		LogFile[500];
 	char		LogLevel[200];
 	char		SyncTime[200];
 	char		GetOnlineInfo[200];
 	char		Name[200];
 	char		Features[200];
+	char		Active[200];
 
 	char		RSSLevel[200];
 	char		FileName[1000];
