@@ -55,7 +55,7 @@ void DebugInfo::Deb(char *format, ...)
 	if (UseDeb) {
 	        va_start(argp, format);
 	        vfprintf(debfile,format,argp);
-//		fflush(debfile);
+		fflush(debfile);
 	        va_end(argp);
 	}
 };
