@@ -18,20 +18,13 @@ BOOLEAN GSM_AllPhones::Feature(char *Name)
 {
 	char Buff[50];
 
-	sprintf(Buff,"-%s-",Name);
+//	(*Debug)->Deb("%s %s\n",Features,Name);
+
+	sprintf(Buff,"%s;",Name);
 	if (strstr(Features,Buff)!=NULL) return TRUE;
 	return FALSE;
 }
 
-BOOLEAN GSM_AllPhones::CompatibilityFeature(char *Name)
-{
-	char Buff[50];
-
-	sprintf(Buff,"-%s-",Name);
-	if (strstr(CFGCompatibility,Buff)!=NULL) return TRUE;
-	return FALSE;
-}
-
 int GSM_AllPhones::GetID()
 {
 	ID+=100;
@@ -45,9 +38,11 @@ GSM_AllPhones::GSM_AllPhones(DebugInfo **Deb)
 	ReceivedLen     = 0;
 	ReceivedPos     = 0;
 	ReplyNum	= 3;
+	Model 		= NULL;
 	Current	 	= NULL;
 	AllPhones       = NULL;
 	Debug	   	= Deb;
+	Features[0]	= 0;
 }
 
 GSM_AllPhones::~GSM_AllPhones()
@@ -65,6 +60,10 @@ GSM_AllPhones::~GSM_AllPhones()
 
 void GSM_AllPhones::Add(GSM_Phone *Phone)
 {
+	list<GSM_Phone_Info>::iterator phoinfo;
+	unsignedstring str;
+	unsigned int i;
+
 	GSM_Phone *Pho;
 
 	if (AllPhones == NULL) {
@@ -74,26 +73,67 @@ void GSM_AllPhones::Add(GSM_Phone *Phone)
 		while (Pho->Next != NULL) Pho = Pho->Next;
 		Pho->Next = Phone;
 	}
+
+	for (phoinfo=Phone->Info.begin(); phoinfo!=Phone->Info.end(); ++phoinfo) {
+		if ((*phoinfo).Features[0] == 0) continue;
+		str.clear();
+		//not effective
+		for (i=0;i<strlen((*phoinfo).Features);i++) {
+			if ((*phoinfo).Features[i] != ';') {
+				str.push_back((*phoinfo).Features[i]);
+			}
+
+			if ((*phoinfo).Features[i] == ';' ||
+			    i==strlen((*phoinfo).Features)-1) {
+				str.push_back(';');
+				if (!strstr((char *)Phone->ModuleFeatures.data(),(const char *)str.data())) {
+					Phone->ModuleFeatures.append(str.data());
+				}
+				str.clear();
+			}
+		}
+	}
+//	str.clear();
+//	str.append(Phone->ModuleFeatures.data());
+//	Phone->ModuleFeatures.clear();
+//	Phone->ModuleFeatures.append(str.data(),str.length()-1);	
 }
 
-GSM_Error GSM_AllPhones::Switch(char *Pho, char *Pro, char *Comp)
+GSM_Error GSM_AllPhones::Switch(char *Pho, char *Pro)
 {
-	GSM_Phone		       *pho;
+	GSM_Phone		        *pho;
 	bool			    	PhoneFound = false, found;
 	list<GSM_Phone_Info>::iterator  phoinfo;
 	int			     	i;
 	char			    	buf[20];
+	unsignedstring			buf2;
 
 	(*Debug)->Deb("[STATE     : switching to phone]\n");
 
-	sprintf(CFGCompatibility,"%s",Comp);
-
 	/* Do we have phone model in phone modules ? If yes, switch */
 	pho=AllPhones;
 	while(1) {
 		for (phoinfo=pho->Info.begin(); phoinfo!=pho->Info.end(); ++phoinfo) {
 			if (strcmp((*phoinfo).Model,Pho)) {
-				continue;
+				if (Pho[0] != 0) {
+					buf2.clear();
+					buf2.append((unsigned char *)Pho);
+					buf2.push_back('/');
+					if (strstr((*phoinfo).Model,(char *)buf2.data())) {
+						PhoneFound=true;
+					} else {
+						buf2.clear();
+						buf2.push_back('/');
+						buf2.append((unsigned char *)Pho);
+						if (strstr((*phoinfo).Model,(char *)buf2.data())) {
+							PhoneFound=true;
+						} else {
+							continue;
+						}
+					}
+				} else {
+					continue;
+				}
 			} else {
 				PhoneFound=true;
 			}
@@ -111,7 +151,7 @@ GSM_Error GSM_AllPhones::Switch(char *Pho, char *Pro, char *Comp)
 							break;
 						}
 					}
-//				      (*Debug)->Deb("Checking \"%s\" used\n",buf);
+//				        (*Debug)->Deb("Checking \"%s\" used\n",buf);
 				}
 
 				i = 0;
@@ -125,17 +165,20 @@ GSM_Error GSM_AllPhones::Switch(char *Pho, char *Pro, char *Comp)
 							break;
 						}
 					}
-//				      (*Debug)->Deb("Checking \"%s\" required\n",buf);
+//				        (*Debug)->Deb("Checking \"%s\" required\n",buf);
 				}
 
 				if (found) {
 					if (Current != NULL) {
 						//disable old
 					}
-					Current	 = pho;
-					Features	= (*phoinfo).Features;
-					Model	   = (*phoinfo).Model;
+					Current	 	= pho;
+					if (Features[0] == 0) {
+						sprintf(Features,"%s",(*phoinfo).Features);
+					}
+					Model	   	= (*phoinfo).Model;
 					CodeNameModel   = (*phoinfo).CodeNameModel;
+//					(*Debug)->Deb("[STATE     : found %s]\n",CodeNameModel);
 					return GSM_Return_Error(GSM_ERR_NONE);
 				}
 			}
@@ -151,27 +194,38 @@ GSM_Error GSM_AllPhones::Switch(char *Pho, char *Pro, char *Comp)
 	return GSM_Return_Error(GSM_ERR_PHONE_STRING_UNKNOWN);
 }
 
-GSM_Error GSM_AllPhones::SwitchToDeviceName(char *Pho, char *Pro, char *Comp)
+GSM_Error GSM_AllPhones::SwitchToDeviceName(char *Pho, char *Pro)
 {
 	GSM_Phone		        *pho;
-	list<GSM_Phone_Info>::iterator  phoinfo;
+	list<GSM_Phone_Info>::iterator  phoinfo,phoinfo2;
 	bool			    	PhoneFound = false;
 
 	(*Debug)->Deb("[STATE     : switching to phone with device name]\n");
 
-	sprintf(CFGCompatibility,"%s",Comp);
-
 	/* Do we have phone model in phone modules ? If yes, switch */
 	pho=AllPhones;
 	while(1) {
 		for (phoinfo=pho->Info.begin(); phoinfo!=pho->Info.end(); ++phoinfo) {
-			if (strcmp((*phoinfo).DeviceModel,Pho)) continue; else PhoneFound=true;
+			if (strcmp((*phoinfo).DeviceModel,Pho)) continue;
+
+			PhoneFound=true;
 			if ((*phoinfo).CompareProtocol(Pro)) {
 				if (Current != NULL) {
 					//disable old
 				}
 				Current	 	= pho;
-				Features	= (*phoinfo).Features;
+
+				//do we have two Nokia 6230 one after one ?
+				//if yes, we need to get firmware code from phone
+				//and base detecting on it
+				if (phoinfo!=pho->Info.end()) {
+					phoinfo2 = ++phoinfo;
+					if (!strcmp((*phoinfo2).DeviceModel,Pho)) return GSM_Return_Error(GSM_ERR_CONVERTED);
+				}
+
+				if (Features[0] == 0) {
+					sprintf(Features,"%s",(*phoinfo).Features);
+				}
 				Model	   	= (*phoinfo).Model;
 				CodeNameModel   = (*phoinfo).CodeNameModel;
 				return GSM_Return_Error(GSM_ERR_NONE);
@@ -188,6 +242,35 @@ GSM_Error GSM_AllPhones::SwitchToDeviceName(char *Pho, char *Pro, char *Comp)
 	return GSM_Return_Error(GSM_ERR_PHONE_STRING_UNKNOWN);
 }
 
+GSM_Error GSM_AllPhones::SwitchToCodeName(char *Pho, char *Pro)
+{
+	GSM_Phone		        *pho;
+	list<GSM_Phone_Info>::iterator  phoinfo,phoinfo2;
+	bool			    	PhoneFound = false;
+
+	(*Debug)->Deb("[STATE     : switching to phone with code name]\n");
+
+	/* Do we have phone model in phone modules ? If yes, switch */
+	pho=AllPhones;
+	while(1) {
+		for (phoinfo=pho->Info.begin(); phoinfo!=pho->Info.end(); ++phoinfo) {
+			if (strcmp((*phoinfo).CodeNameModel,Pho)) continue;
+
+			if (Features[0] == 0) {
+				sprintf(Features,"%s",(*phoinfo).Features);
+			}
+			Model	   	= (*phoinfo).Model;
+			CodeNameModel   = (*phoinfo).CodeNameModel;
+			return GSM_Return_Error(GSM_ERR_NONE);
+		}
+		if (pho->Next == NULL) break;
+		pho = pho->Next;
+	}
+
+	/* Unknown phone model */
+	return GSM_Return_Error(GSM_ERR_PHONE_STRING_UNKNOWN);
+}
+
 int GSM_AllPhones::GetNext(GSM_Phone **Pho)
 {
 	if ((*Pho) == NULL) {
@@ -237,6 +320,7 @@ bool GSM_Phone_Info::CompareProtocol(char *Pro)
 
 GSM_Phone::GSM_Phone(DebugInfo **Deb, GSM_Device **Dev, GSM_AllProtocols **Prot, GSM_AllPhones **Pho)
 {
+	ModuleFeatures[0]	= 0;
 	UserReply       	= NULL;
 	SMSSendReply    	= NULL;
 	Next	    		= NULL;
@@ -265,7 +349,7 @@ GSM_Error GSM_Phone::Read(int RequestID, void *Struct)
 
 	if ((*Phones)->ReceivedLen == (*Phones)->ReceivedPos) {
 		(*Phones)->ReceivedPos = 0;
-		(*Phones)->ReceivedLen = 5000;
+		(*Phones)->ReceivedLen = 50000;
 		error = (*Device)->Read((*Phones)->ReceivedBuffer,&(*Phones)->ReceivedLen);
 		if (error.Code != GSM_ERR_NONE) {
 //		      	(*Phones)->ReceivedLen = 0;
@@ -396,7 +480,7 @@ bool GSM_Phone::Ans(char *MsgTyp, int SubTypeChar, unsigned char SubType, int Re
 	return true;
 }
 
-GSM_Error GSM_Phone::Open(char *ID)
+GSM_Error GSM_Phone::Open(char *FrameID)
 {
 	(*Debug)->Deb("[STATE     : opening phone %s]\n",ModuleName);
 	return GSM_Return_Error(GSM_ERR_NONE);
@@ -692,7 +776,7 @@ GSM_Error GSM_Phone::GetSMSMMSFolders(GSM_SMSMMSFolders *Folders)
 	return GSM_Return_Error(GSM_ERR_NOT_SUPPORTED);
 }
 
-GSM_Error GSM_Phone::GetNextSMSMMSIDFromFolder(BOOLEAN start, GSM_SMSMMSFoldersSubEntry *SMSFolder, GSM_SMSList *SMS, GSM_MMSFile *MMS, int *Current, int *MaxInFolder)
+GSM_Error GSM_Phone::GetNextSMSMMSIDFromFolder(BOOLEAN start, GSM_SMSMMSFoldersSubEntry *SMSFolder, GSM_SMSList *SMS, GSM_MMSEntry *MMS, int *Current, int *MaxInFolder)
 {
 	return GSM_Return_Error(GSM_ERR_NOT_SUPPORTED);
 }
