@@ -8,9 +8,8 @@
 #include "../service/gsmpbk.h"
 #include "../service/gsmcal.h"
 #include "../service/gsmfiles.h"
-#include "../service/gsmdata.h"
-#include "../service/sms/gsmsms.h"
-#include "../service/sms/smsmulti.h"
+#include "../service/smsmms/gsmsms.h"
+#include "../service/smsmms/gsmmsg.h"
 
 using namespace std;
 
@@ -89,11 +88,12 @@ typedef struct {
  */
 class GSM_Phone
 {
-        friend class            GSM_AllPhones;
+        friend class            	GSM_AllPhones;
 public:
-        list <GSM_Phone_Info>   Info;
-        char                    *ModuleName,*ModulesRequired,*ModulesUsed;
-	GSM_FileFolderInfoLists FoldersCache;
+        list <GSM_Phone_Info>   	Info;
+        char                    	*ModuleName,*ModulesRequired,*ModulesUsed;
+	unsignedstring			ModuleFeatures;
+	GSM_FileFolderInfoLists 	FoldersCache;
 	GSM_FileFolderInfoListsSubEntry *FoldersCacheSubEntry;
 
         GSM_Phone               (DebugInfo **Deb, GSM_Device **Dev, GSM_AllProtocols **Prot, GSM_AllPhones **Pho);
@@ -108,7 +108,7 @@ public:
         void                    SetSMSSendReply(void(*SMSSndReply)(int TPMR));
 	GSM_Error 		ReadFolderToCache(wchar_t *ID, GSM_FileFolderInfoList **List);
 
-        virtual GSM_Error       Open(char *ID);
+        virtual GSM_Error       Open(char *FrameID);
         virtual GSM_Error       Close();
 
         //phone info
@@ -150,7 +150,7 @@ public:
         virtual GSM_Error       SetSMSC(GSM_SMSC *SMSC);
         //sms & mms
 	virtual GSM_Error 	GetSMSMMSFolders(GSM_SMSMMSFolders *Folders);
-	virtual GSM_Error       GetNextSMSMMSIDFromFolder(BOOLEAN start, GSM_SMSMMSFoldersSubEntry *SMSFolder, GSM_SMSList *SMS, GSM_MMSFile *MMS, int *Current, int *MaxInFolder);
+	virtual GSM_Error       GetNextSMSMMSIDFromFolder(BOOLEAN start, GSM_SMSMMSFoldersSubEntry *SMSFolder, GSM_SMSList *SMS, GSM_MMSEntry *MMS, int *Current, int *MaxInFolder);
         //filesystem
         virtual GSM_Error       GetFileFolderInfo(FileFolderInfo *FInfo);
         virtual GSM_Error       GetNextRootFolderID(wchar_t *ID, GSM_MemoryType *MemType);
@@ -188,18 +188,18 @@ protected:
 class GSM_AllPhones
 {
         friend class            GSM_Phone;
+	friend class		GSM_StateMachine;
 public:
         GSM_Phone               *Current;
-        char                    CFGCompatibility[200];
 
         GSM_AllPhones           (DebugInfo **Deb);
         ~GSM_AllPhones          ();
 
         void                    Add                (GSM_Phone *Phone);
-        GSM_Error               Switch             (char *Pho, char *Pro, char *Comp);
-        GSM_Error               SwitchToDeviceName (char *Pho, char *Pro, char *Comp);
+        GSM_Error               Switch             (char *Pho, char *Pro);
+        GSM_Error               SwitchToDeviceName (char *Pho, char *Pro);
+	GSM_Error 		SwitchToCodeName   (char *Pho, char *Pro);
         BOOLEAN                 Feature            (char *Name);
-        BOOLEAN                CompatibilityFeature(char *Name);
         int                     GetNext            (GSM_Phone **Pho);
         int                     GetID              ();
 private:
@@ -208,11 +208,11 @@ private:
         GSM_Phone               *AllPhones;
         DebugInfo               **Debug;
 
-        char                    *Features;
+        char                    Features[2000];
         char                    *Model;
         char                    *CodeNameModel;
 
-        unsigned char           ReceivedBuffer[5000];
+        unsigned char           ReceivedBuffer[50000];
         int                     ReceivedLen, ReceivedPos;
 
         int                     ReplyNum;
