@@ -1,4 +1,4 @@
-/* (C) 2003 - 2005 by Marcin Wiacek www.mwiacek.com */
+/* (C) 2003 - 2007 by Marcin Wiacek www.mwiacek.com */
 
 #include "../../../../cfg/config.h" //msvc2005
 #include "../../../misc/coding/coding.h"
@@ -212,12 +212,12 @@ GSM_Error GSM_Phone_N6110::ReplySetPBK(GSM_Protocol_Message *msg, DebugInfo **De
 
 GSM_Error GSM_Phone_N6110::SetPBK(GSM_PBKEntry *Entry)
 {
-	char		    c;
-	int		     i;
-	GSM_PBKSubEntry	 *SubEntry;
-	wchar_t		 *Name = NULL, *Phone = NULL;
-	unsignedstring	  Buffer;
-	unsigned char	   Buff[] = {
+	char		    	c;
+	int		     	i;
+	GSM_PBKSubEntry	 	*SubEntry;
+	wchar_t		 	*Name = NULL, *Phone = NULL;
+	unsignedstring	  	Buffer;
+	unsigned char	   	Buff[] = {
 		NOKIA_FRAME1, 0x04,
 		0x00,	   // memory type
 		0x00};	  // location
@@ -420,10 +420,10 @@ GSM_Error GSM_Phone_N6110::ReplyAddCalendar(GSM_Protocol_Message *msg, DebugInfo
 
 GSM_Error GSM_Phone_N6110::AddCalendar(GSM_CalendarEntry *Entry)
 {
-	unsignedstring	  Buffer,Buffer2;
+	unsignedstring	  	Buffer,Buffer2;
 	GSM_CalendarSubEntry    *SubEntry, *Text = NULL, *Phone = NULL;
 	GSM_CalendarSubEntry    *DateStart = NULL, *Alarm = NULL;
-	int		     i;
+	int		     	i;
 
 	SubEntry = NULL;
 	while (Entry->GetNext(&SubEntry) == TRUE) {
@@ -601,6 +601,39 @@ GSM_Error GSM_Phone_N6110::ReplyGetSMS(GSM_Protocol_Message *msg, DebugInfo **De
 	return GSM_Return_Error(GSM_ERR_UNKNOWN);
 }
 
+GSM_Error GSM_Phone_N6110::GetNextSMSMMSIDFromFolder(BOOLEAN start, GSM_SMSMMSFoldersSubEntry *SMSFolder, GSM_SMSList *SMS, GSM_MMSEntry *MMS, int *Current, int *MaxInFolder)
+{
+	wchart		SMSID;
+	GSM_Error	error;
+	unsigned char	Buff[] = {NOKIA_FRAME1, 0x07, 0x02,
+				  0x00,		 // SMS location
+				  0x01, 0x64};
+
+	if (start == TRUE) {
+		SMSStatus.Memory = MEM_SIM;
+		error = GetSMSStatus(&SMSStatus);
+		if (error.Code != GSM_ERR_NONE) return error;
+		SMSLocation = 0;
+	}
+
+	SMSLocation++;
+	if (SMSLocation > SMSStatus.SMSFree + SMSStatus.SMSRead + SMSStatus.SMSUnRead) return GSM_Return_Error(GSM_ERR_EMPTY);
+
+	Buff[5] = SMSLocation;
+
+	(*Debug)->Deb("SENT: getting SMS\n");
+	error = Write(Buff, sizeof(Buff), 0x14, 4, ID_GetSMS+ID, SMS); 
+	if (error.Code!=GSM_ERR_NONE) return error;
+
+	MMS->Folder     = 0;
+	*Current	= SMSLocation;
+	*MaxInFolder    = SMSStatus.SMSFree + SMSStatus.SMSRead + SMSStatus.SMSUnRead;
+
+	SetSMSLocations(SMS, SMS->Folder, SMSLocation);
+
+	return error;
+}
+
 GSM_Error GSM_Phone_N6110::GetSMSC(GSM_SMSC *SMSC)
 {
 	return DCT3->GetSMSC(SMSC);
@@ -608,14 +641,14 @@ GSM_Error GSM_Phone_N6110::GetSMSC(GSM_SMSC *SMSC)
 
 GSM_Error GSM_Phone_N6110::ReplySetSMS(GSM_Protocol_Message *msg, DebugInfo **Debug, unsigned char *S)
 {
-	GSM_SMSList *List = (GSM_SMSList *)S;
+	GSM_SMSList 		*List = (GSM_SMSList *)S;
 	GSM_SMSListSubEntry     *SubEntry = NULL;
 
 	switch (msg->Buffer.data()[3]) {
 	case 0x05:
-			while (List->GetNext(&SubEntry) == TRUE) {
-				SetSMSLocations(List, List->Folder, msg->Buffer.data()[5]);
-			}
+		while (List->GetNext(&SubEntry) == TRUE) {
+			SetSMSLocations(List, List->Folder, msg->Buffer.data()[5]);
+		}
 		return GSM_Return_Error(GSM_ERR_NONE);
 	case 0x06:
 		break;
@@ -711,9 +744,9 @@ GSM_Error GSM_Phone_N6110::ReplyDeleteSMS(GSM_Protocol_Message *msg, DebugInfo *
 
 GSM_Error GSM_Phone_N6110::DeleteSMS(GSM_SMSList *List)
 {
-	unsigned char	   FolderID;
-	int		     Location;
-	unsigned char	   Buff[] = {NOKIA_FRAME1, 0x0A, 0x02,
+	unsigned char	   	FolderID;
+	int		     	Location;
+	unsigned char	   	Buff[] = {NOKIA_FRAME1, 0x0A, 0x02,
 					  0x00};		// SMS location
 
 	GetSMSLocations(List, &FolderID, &Location);
@@ -722,3 +755,15 @@ GSM_Error GSM_Phone_N6110::DeleteSMS(GSM_SMSList *List)
 	(*Debug)->Deb("SENT: deleting SMS\n");
 	return Write(Buff, sizeof(Buff), 0x14, 4, ID_DelSMS+ID, List); 
 }
+
+GSM_Error GSM_Phone_N6110::GetSMSMMSFolders(GSM_SMSMMSFolders *Folders)
+{
+	wchart ID;
+
+	ID.clear(); ID.push_back('1');
+	Folders->Add(StringToUnicodeReturn("Inbox"),FALSE,TRUE,FALSE,MEM_SIM,&ID,1,-1);
+	ID.clear(); ID.push_back('2');
+	Folders->Add(StringToUnicodeReturn("Outbox"),FALSE,FALSE,FALSE,MEM_SIM,&ID,2,-1);
+
+        return GSM_Return_Error(GSM_ERR_NONE);
+}
