@@ -9,7 +9,7 @@
 
 GSM_Error GSM_Phone_N6510::GetNextCalendar(GSM_CalendarEntry *Entry, BOOLEAN start, int *Current, int *Max)
 {
-	if ((*Phones)->Feature("cal62")==TRUE) {
+	if ((*Phones)->Feature("calendar1")==TRUE) {
 		return DCT34->GetNextCalendar1(Entry,start,Current,Max);
 	} else {
 		return GetNextCalendar3NoteToDo2(Entry,start,Current,Max,&Entry->Location,0x00,ID_GetCalendar);
@@ -18,7 +18,7 @@ GSM_Error GSM_Phone_N6510::GetNextCalendar(GSM_CalendarEntry *Entry, BOOLEAN sta
 
 GSM_Error GSM_Phone_N6510::AddCalendar(GSM_CalendarEntry *Entry)
 {
-	if ((*Phones)->Feature("cal62")==TRUE) {
+	if ((*Phones)->Feature("calendar1")==TRUE) {
 		return DCT34->AddCalendar1(Entry);
 	} else {
 		return AddCalendar3(Entry);
@@ -102,7 +102,7 @@ GSM_Error GSM_Phone_N6510::DeleteNote(GSM_NoteEntry *Entry)
 
 GSM_Error GSM_Phone_N6510::GetNextToDo(GSM_ToDoEntry *Entry, BOOLEAN start, int *Current, int *Max)
 {
-	if ((*Phones)->Feature("todo63")) return GetNextToDo1(Entry, start, Current, Max);
+	if ((*Phones)->Feature("todo1")) return GetNextToDo1(Entry, start, Current, Max);
 	if ((*Phones)->Feature("notodo")) return GSM_Return_Error(GSM_ERR_NOT_SUPPORTED);
 
 	return GetNextCalendar3NoteToDo2(Entry, start, Current, Max, &Entry->Location, 0x01, ID_GetToDo);
@@ -110,7 +110,7 @@ GSM_Error GSM_Phone_N6510::GetNextToDo(GSM_ToDoEntry *Entry, BOOLEAN start, int
 
 GSM_Error GSM_Phone_N6510::AddToDo(GSM_ToDoEntry *Entry)
 {
-	if ((*Phones)->Feature("todo63")) return AddToDo1(Entry);
+	if ((*Phones)->Feature("todo1")) return AddToDo1(Entry);
 	if ((*Phones)->Feature("notodo")) return GSM_Return_Error(GSM_ERR_NOT_SUPPORTED);
 
 	return AddToDo2(Entry);
@@ -120,7 +120,7 @@ GSM_Error GSM_Phone_N6510::DeleteToDo(GSM_ToDoEntry *Entry)
 {
 	GSM_CalendarEntry Cal;
 
-	if ((*Phones)->Feature("todo63") || (*Phones)->Feature("notodo")) return GSM_Return_Error(GSM_ERR_NOT_SUPPORTED);
+	if ((*Phones)->Feature("todo1") || (*Phones)->Feature("notodo")) return GSM_Return_Error(GSM_ERR_NOT_SUPPORTED);
 
 	Cal.Location = Entry->Location;
 
@@ -131,7 +131,7 @@ GSM_Error GSM_Phone_N6510::DeleteAllToDo()
 {
 	unsigned char req[] = {NOKIA_FRAME1, 0x11};
 
-	if (!(*Phones)->Feature("todo63")) return GSM_Return_Error(GSM_ERR_NOT_SUPPORTED);
+	if (!(*Phones)->Feature("todo1")) return GSM_Return_Error(GSM_ERR_NOT_SUPPORTED);
 
 	(*Debug)->Deb("SENT: Deleting all ToDo\n");
 	return Write(req, sizeof(req), 0x55, 4, ID_DeleteToDo+ID,NULL);
@@ -498,8 +498,8 @@ GSM_Error GSM_Phone_N6510::FindCalendarNoteType3(GSM_CalendarEntry *Entry, int *
 		CalendarLocations2.Locations.push_back(CalendarLocations.Locations.data()[i]);
 	}
 
-	if ((*Phones)->Feature("cal62")==TRUE || (*Phones)->Feature("cal65")==TRUE ||
-	    (*Phones)->Feature("cal35")==TRUE) {
+	if ((*Phones)->Feature("calendar1")==TRUE || (*Phones)->Feature("calendar65")==TRUE ||
+	    (*Phones)->Feature("calendar35")==TRUE) {
 		error = DCT34->AddCalendar2(Entry);
 	} else {
 		/* First method 1 was used for meeting only
@@ -607,6 +607,8 @@ GSM_Error GSM_Phone_N6510::AddCalendar3(GSM_CalendarEntry *Entry)
 		0x00, 0x00, 0x00};
 	int NoteID;
 
+	Entry->TypeSetError = GSM_Return_Error(GSM_ERR_NONE);
+
 	SubEntry = NULL;
 	while (Entry->GetNext(&SubEntry) == TRUE) {
 		SubEntry->SetError = GSM_Return_Error(GSM_ERR_NONE);
@@ -744,8 +746,8 @@ GSM_Error GSM_Phone_N6510::AddCalendar3(GSM_CalendarEntry *Entry)
 	}
 
 	if (Location != NULL && Entry->Type == Calendar_Type_Meeting) {
-		if ((*Phones)->Feature("cal62")==TRUE || (*Phones)->Feature("cal65")==TRUE ||
-		    (*Phones)->Feature("cal35")==TRUE) {
+		if ((*Phones)->Feature("calendar1")==TRUE || (*Phones)->Feature("calendar65")==TRUE ||
+		    (*Phones)->Feature("calendar35")==TRUE) {
 		} else {
 			req[50] = UnicodeLength(Location->GetText());
 			NokiaSetUnicodeString(Location->GetText(),&Buffer);
