@@ -211,7 +211,7 @@ GSM_Error GSM_Phone_N6510::GetSMS2(GSM_SMSList *List, GSM_File *File)
         return GSM_Return_Error(GSM_ERR_NONE);
 }
 
-GSM_Error GSM_Phone_N6510::GetNextSMSMMSIDFromFolder2(BOOLEAN start, GSM_SMSMMSFoldersSubEntry *SMSFolder, GSM_SMSList *SMS, GSM_MMSFile *MMS, int *Current, int *MaxInFolder)
+GSM_Error GSM_Phone_N6510::GetNextSMSMMSIDFromFolder2(BOOLEAN start, GSM_SMSMMSFoldersSubEntry *SMSFolder, GSM_SMSList *SMS, GSM_MMSEntry *MMS, int *Current, int *MaxInFolder)
 {
 	GSM_Error	error;
 	GSM_File 	File;
@@ -390,11 +390,22 @@ GSM_Error GSM_Phone_N6510::GetSMSMMSFolders1(GSM_SMSMMSFolders *Folders)
 	wchart 				ID2;
 	GSM_SMSMMSFoldersSubEntry  	*SubEntry2;
 
-	(*Debug)->Deb("SENT: getting SMS folders\n");
-	error = Write(Buff, sizeof(Buff), 0x14, 4, ID_GetSMSFolders+ID, Folders);
-	if (error.Code != GSM_ERR_NONE) return error;
+	if ((*Phones)->Feature("s40_30") && (*Phones)->Feature("sms1")) {
+		ID2.clear(); ID2.push_back('1');
+		Folders->Add(StringToUnicodeReturn("SIM"),FALSE,FALSE,FALSE,MEM_SIM,&ID2,1,-1);
+		ID2.clear(); ID2.push_back('2');
+		Folders->Add(StringToUnicodeReturn("Inbox"),FALSE,TRUE,FALSE,MEM_SIM,&ID2,2,-1);
+		ID2.clear(); ID2.push_back('3');
+		Folders->Add(StringToUnicodeReturn("Sent items"),FALSE,FALSE,FALSE,MEM_SIM,&ID2,3,-1);
+		ID2.clear(); ID2.push_back('4');
+		Folders->Add(StringToUnicodeReturn("Saved items"),FALSE,FALSE,FALSE,MEM_SIM,&ID2,4,-1);
+	} else {
+		(*Debug)->Deb("SENT: getting SMS folders\n");
+		error = Write(Buff, sizeof(Buff), 0x14, 4, ID_GetSMSFolders+ID, Folders);
+		if (error.Code != GSM_ERR_NONE) return error;
+	}
 
-	if ((*Phones)->Feature("nofile")) return error;
+	if ((*Phones)->Feature("nofilesystem")) return error;
 
 	SubEntry2 = NULL;
 	while (Folders->GetNext(&SubEntry2)) Num++;
@@ -439,7 +450,7 @@ GSM_Error GSM_Phone_N6510::GetSMSMMSFolders1(GSM_SMSMMSFolders *Folders)
 	}
 
 	//6230i
-	if (!(*Phones)->Feature("nofile") && !(*Phones)->Feature("file1only")) {
+	if (!(*Phones)->Feature("nofilesystem") && !(*Phones)->Feature("filesystem1only")) {
 		error = ReadFolderToCache(StringToUnicodeReturn("d:\\predefmessages"), &List);
 		if (error.Code == GSM_ERR_FILE_FOLDER_NOT_EXIST) return GSM_Return_Error(GSM_ERR_NONE);
 		if (error.Code != GSM_ERR_NONE) return error;
@@ -679,7 +690,7 @@ GSM_Error GSM_Phone_N6510::GetSMS1(GSM_SMSList *List, wchart SMS_ID)
 	return Write(Buff, sizeof(Buff), 0x14, 4, ID_GetSMS+ID, List);
 }
 
-GSM_Error GSM_Phone_N6510::GetNextSMSMMSIDFromFolder1(BOOLEAN start, GSM_SMSMMSFoldersSubEntry *SMSFolder, GSM_SMSList *SMS, GSM_MMSFile *MMS, int *Current, int *MaxInFolder)
+GSM_Error GSM_Phone_N6510::GetNextSMSMMSIDFromFolder1(BOOLEAN start, GSM_SMSMMSFoldersSubEntry *SMSFolder, GSM_SMSList *SMS, GSM_MMSEntry *MMS, int *Current, int *MaxInFolder)
 {
 	GSM_Error	error;
 	wchart		SMSID;
@@ -740,6 +751,8 @@ GSM_Error GSM_Phone_N6510::GetNextSMSMMSIDFromFolder1(BOOLEAN start, GSM_SMSMMSF
 			case GSM_ERR_NONE:
 				FoldersCache.AddSubEntry(FoldersCacheSubEntry);
 				SMSCache2 = FoldersCacheSubEntry;
+				SMSSubEntry = NULL;
+				while (FoldersCacheSubEntry->Info.GetNext(&SMSSubEntry)) SMSListMax++;
 				FoldersCacheSubEntry = NULL;
 				break;
 			case GSM_ERR_FOLDER_PART:
@@ -747,9 +760,6 @@ GSM_Error GSM_Phone_N6510::GetNextSMSMMSIDFromFolder1(BOOLEAN start, GSM_SMSMMSF
 				SMSCache2 = FoldersCacheSubEntry;
 				FoldersCacheSubEntry = NULL;
 				//no break
-			case GSM_ERR_FOLDER_MORE:
-				SMSListMax++;
-				//no break;
 			default:
 				return GetNextSMSFolder2;
 			}
@@ -1244,30 +1254,30 @@ GSM_Error GSM_Phone_N6510::SendSMS(GSM_SMSEntry *SMS)
 
 GSM_Error GSM_Phone_N6510::GetSMSStatus(GSM_SMSStatus *Status)
 {
-	if ((*Phones)->Feature("s40_30")==TRUE && !(*Phones)->CompatibilityFeature("6510_sms1")) return GSM_Return_Error(GSM_ERR_NOT_SUPPORTED);
+	if ((*Phones)->Feature("s40_30")==TRUE && !(*Phones)->Feature("sms1")) return GSM_Return_Error(GSM_ERR_NOT_SUPPORTED);
 	return GetSMSStatus1(Status);
 }
 
 GSM_Error GSM_Phone_N6510::GetSMSMMSFolders(GSM_SMSMMSFolders *Folders)
 {
-	if ((*Phones)->Feature("s40_30")==TRUE && !(*Phones)->CompatibilityFeature("6510_sms1")) return GetSMSMMSFolders2(Folders);
+	if ((*Phones)->Feature("s40_30")==TRUE && !(*Phones)->Feature("sms1")) return GetSMSMMSFolders2(Folders);
 	return GetSMSMMSFolders1(Folders);
 }
 
 GSM_Error GSM_Phone_N6510::SetSMS(GSM_SMSList *List)
 {
-	if ((*Phones)->Feature("s40_30")==TRUE && !(*Phones)->CompatibilityFeature("6510_sms1")) return GSM_Return_Error(GSM_ERR_NOT_SUPPORTED);
+	if ((*Phones)->Feature("s40_30")==TRUE && !(*Phones)->Feature("sms1")) return GSM_Return_Error(GSM_ERR_NOT_SUPPORTED);
 	return SetSMS1(List);
 }
 
 GSM_Error GSM_Phone_N6510::DeleteSMS(GSM_SMSList *List)
 {
-	if ((*Phones)->Feature("s40_30")==TRUE && !(*Phones)->CompatibilityFeature("6510_sms1")) return DeleteSMS2(List);
+	if ((*Phones)->Feature("s40_30")==TRUE && !(*Phones)->Feature("sms1")) return DeleteSMS2(List);
 	return DeleteSMS1(List);
 }
 
-GSM_Error GSM_Phone_N6510::GetNextSMSMMSIDFromFolder(BOOLEAN start, GSM_SMSMMSFoldersSubEntry *SMSFolder, GSM_SMSList *SMS, GSM_MMSFile *MMS, int *Current, int *MaxInFolder)
+GSM_Error GSM_Phone_N6510::GetNextSMSMMSIDFromFolder(BOOLEAN start, GSM_SMSMMSFoldersSubEntry *SMSFolder, GSM_SMSList *SMS, GSM_MMSEntry *MMS, int *Current, int *MaxInFolder)
 {
-	if ((*Phones)->Feature("s40_30")==TRUE && !(*Phones)->CompatibilityFeature("6510_sms1")) return GetNextSMSMMSIDFromFolder2(start, SMSFolder, SMS,MMS,Current, MaxInFolder);
+	if ((*Phones)->Feature("s40_30")==TRUE && !(*Phones)->Feature("sms1")) return GetNextSMSMMSIDFromFolder2(start, SMSFolder, SMS,MMS,Current, MaxInFolder);
 	return GetNextSMSMMSIDFromFolder1(start, SMSFolder, SMS,MMS,Current, MaxInFolder);
 }
