@@ -25,7 +25,7 @@ if(Ans("\x03",0x03,0x04,ID_GetPBKStatus+ID,&AS))     	return ReplyGetPBKStatus
 if(Ans("\x03",0x03,0x08,ID_GetPBK+ID, &AS))     	return ReplyGetPBK 			(msg,Debug,(unsigned char *)Struct);
 if(Ans("\x03",0x03,0x0C,ID_SetPBK+ID, &AS))     	return DCT34->ReplySetPBK 		(msg,Debug,(unsigned char *)Struct);
 if(Ans("\x03",0x03,0x10,ID_DelPBK+ID, &AS))     	return DCT34->ReplyDelPBK 		(msg,Debug,(unsigned char *)Struct);
-if(Ans("\x03",0x03,0x26,ID_GetPBK+ID3, &AS))     	return DCT34->ReplyGetPBKFeatures 	(msg,Debug,(unsigned char *)Struct);
+if(Ans("\x03",0x03,0x26,ID_GetPBK+ID3, &AS))     	return ReplyGetPBKFeatures 		(msg,Debug,(unsigned char *)Struct);
 
 if(Ans("\x13",0x03,0x02,ID_AddCalendar+ID3,&AS))   	return DCT34->ReplyAddCalendar1		(msg,Debug,(unsigned char *)Struct);
 if(Ans("\x13",0x03,0x04,ID_AddCalendar+ID3,&AS))   	return DCT34->ReplyAddCalendar1		(msg,Debug,(unsigned char *)Struct);
@@ -97,6 +97,31 @@ if(Ans("\xD2",0x02,0x00,ID_GetID+ID3,      &AS))     	return DCT34->ReplyGetID
         return GSM_Return_Error(GSM_ERR_FRAME_TYPE_UNKNOWN);
 }
 
+GSM_Error GSM_Phone_N6510::ReplyGetPBKFeatures(GSM_Protocol_Message *msg, DebugInfo **Debug, unsigned char *S)
+{
+	GSM_PBK_Features *Entry = (GSM_PBK_Features *)S;
+	int 		 i,pos=6;
+
+	(*Debug)->Deb("  Features: ");
+	Entry->Types.clear();
+	for (i=0;i<msg->Buffer.data()[5]-1;i++) {
+		(*Debug)->Deb("%02x ",msg->Buffer.data()[pos+4]);
+		Entry->Types.push_back(msg->Buffer.data()[pos+4]);
+		pos+=msg->Buffer.data()[pos+3];
+	}
+	(*Debug)->Deb("\n");
+
+	(*Debug)->Deb("  Phones: ");
+	Entry->Numbers.clear();
+	for (i=0;i<msg->Buffer.data()[pos+4];i++) {
+		(*Debug)->Deb("%02x ",msg->Buffer.data()[pos+5+i]);
+		Entry->Numbers.push_back(msg->Buffer.data()[pos+5+i]);
+	}
+	(*Debug)->Deb("\n");
+
+	return GSM_Return_Error(GSM_ERR_NONE);
+}
+
 GSM_Error GSM_Phone_N6510::ReplyGetIMEI(GSM_Protocol_Message *msg, DebugInfo **Debug, unsigned char *IMEI)
 {
 	memcpy(IMEI,msg->Buffer.data()+10, 16);
