@@ -18,6 +18,9 @@ public:
 		Info.push_back(GSM_Protocol_Info("bluetooth","bluerfphonet",false, true));
 		Info.push_back(GSM_Protocol_Info("infrared", "irdaphonet",  true,  false));
 #else
+#ifdef BLUEZ
+		Info.push_back(GSM_Protocol_Info("bluetooth","bluerfphonet",true, true));
+#endif
 		Info.push_back(GSM_Protocol_Info("infrared", "irdaphonet",  true,  true));
 #endif
         }
