@@ -79,47 +79,6 @@ typedef enum {
 GSM_MemoryType 	GSM_GetMemoryType(char *Buffer);
 char 		*GSM_GetMemoryName(GSM_MemoryType Type);
 
-GSM_Error 	GSM_DecodeSMSNumber(wchar_t *Destination, const unsigned char *Source, int len, BOOLEAN semioctets);
-GSM_Error 	GSM_EncodeSMSNumber(unsignedstring *Destination, wchar_t *Source, BOOLEAN semioctets);
-GSM_Error 	GSM_DecodeSMSText(wchar_t *Destination, const unsigned char *Source, int len, int len3, int udhlen);
-GSM_Error 	GSM_EncodeSMSText(unsigned char *Destination, const wchar_t *Source, int *len, int maxlen, int udhlen);
-
-class GSM_SMSMMSFoldersSubEntry
-{
-public:
-	GSM_SMSMMSFoldersSubEntry();
-	~GSM_SMSMMSFoldersSubEntry();
-
-	int				Number;
-	int				OtherNumber;
-	BOOLEAN				FileSystem;
-	BOOLEAN				Inbox;
-	BOOLEAN				MMS;
-	GSM_MemoryType			Memory;
-	wchart				ID;
-
-	void				SetName(wchar_t *N);
-	wchar_t 			*GetName();
-	void				SetNext(GSM_SMSMMSFoldersSubEntry *Nxt);
-	GSM_SMSMMSFoldersSubEntry	*GetNext();
-private:
-	GSM_SMSMMSFoldersSubEntry	*Next;
-	wchar_t				*Name;
-};
-
-class GSM_SMSMMSFolders
-{
-public:
-	GSM_SMSMMSFolders();
-	~GSM_SMSMMSFolders();
-
-	BOOLEAN 			GetNext(GSM_SMSMMSFoldersSubEntry **En);
-	GSM_Error	 		Add(wchar_t *Name, BOOLEAN FF, BOOLEAN Inbox, BOOLEAN MMS, GSM_MemoryType mem, wchart *ID, int Num, int OtherNum);
-	void 				ClearAll();	
-private:
-	GSM_SMSMMSFoldersSubEntry	*Entries;
-};
-
 GSM_Error CheckRSS (unsignedstring *StableStr, unsignedstring *TestStr);
 
 #endif
