@@ -113,6 +113,32 @@ void Identify(GSM_StateMachine *s, GSM_GPlusConfig *CFG, int argc, char *argv[])
         GSM_Error 		error;
 	unsigned char 		IMEI[20], Model[50], Model2[50], Firm[50], Man[50], Firm2[50];
 
+
+    GSM_SMSMMSDecodedEntry Decoded;
+    GSM_SMSMMSDecodedSubEntry *Decoded2;
+    GSM_SMSList List;
+    GSM_SMSListSubEntry *SMS2;
+    int i,left;
+    wchar_t x[2];
+    List.ClearAll();
+    Decoded2 = new GSM_SMSMMSDecodedSubEntry;
+    Decoded2->Type = MMS_File;
+    Decoded2->Text.append(StringToUnicodeReturn("text/plain"));
+//    UnicodeToUTF8(StringToUnicodeReturn("ddddddddddddddddddddddddxxxxxxxxdddddddddddddddddddddddddddddddddddddddddddddddddddddddddddddddddddddddddddddddddddddddddddddddddddddddddddddddddddddddddddddddd"), &Decoded2->File.Buffer);
+  //  x[0]=1*256+5;
+x[0]='{';
+    x[1] = 0;
+    UnicodeToUTF8(x, &Decoded2->File.Buffer);
+    Decoded.Add(Decoded2);
+    Decoded.SaveToSMS(&List, SMS_Text_Short,&left);
+    i=0;
+    SMS2 = NULL;
+    while (List.GetNext(&SMS2)) {
+        i++;
+	printf("%i\n",SMS2->GetSMS()->UserData.size());
+    }
+    printf("sms num %i %i\n",i,left);
+
 //unsignedstring x;
 //int len2,w,z,m;
 //wchar_t buff[50];
