@@ -262,7 +262,7 @@ int DisplaySingleSMS(GSM_SMSEntry *SMS, GSM_Backup *Backup)
 			}			
 		}
 		if (SMS->GetClass() != -1) 	    printf("    SMS Class                   : %i\n",SMS->GetClass());
-		if (SMS->SenderSMSCReply() == TRUE) printf("    SMSC reply                  : yes\n");
+		if (SMS->GetSenderSMSCReply() == TRUE) printf("    SMSC reply                  : yes\n");
 
 		error = SMS->GetUDH(&UDH);
 		PrintError(error);
@@ -426,7 +426,7 @@ void GetAllSMS(GSM_StateMachine *s, GSM_GPlusConfig *CFG, int argc, char *argv[]
 	unsignedstring			Buffer2, UDH;
 	GSM_Error			error,error2;
 	GSM_SMSList			Entry;
-	GSM_MMSFile		 	Entry2;
+	GSM_MMSEntry		 	Entry2;
 	GSM_SMSListSubEntry		*SubEntry;
 	GSM_SMSMMSFolders		Folders;
 	GSM_SMSMMSFoldersSubEntry  	*SubFolder2;
@@ -503,6 +503,7 @@ void GetAllSMS(GSM_StateMachine *s, GSM_GPlusConfig *CFG, int argc, char *argv[]
 		//mms
 		if (Entry.Folder == 0) continue;
 
+
 		if (CurrentFolder != Entry.Folder) continue;
 
 		smsnum++;
@@ -563,7 +564,7 @@ void GetEachSMS(GSM_StateMachine *s, GSM_GPlusConfig *CFG, int argc, char *argv[
 	unsignedstring			Buffer2, UDH;
 	GSM_Error			error,error2;
 	GSM_SMSList			*Entry;
-	GSM_MMSFile 		Entry2;
+	GSM_MMSEntry 		Entry2;
 	GSM_SMSListSubEntry		*SubEntry;
 	GSM_SMSMMSFolders		Folders;
 	GSM_SMSMMSFoldersSubEntry  	*SubFolder2;
