@@ -62,8 +62,6 @@ void MainFrm::CreateGUIControls()
 
 	WxStatusBar1 = new wxStatusBar(this, ID_WXSTATUSBAR1);
 
-	WxSaveFileDialog1 =  new wxFileDialog(this, wxT("Choose a file"), wxT(""), wxT(""), wxT("*.*"), wxSAVE | wxOVERWRITE_PROMPT);
-
 	WxOpenFileDialog1 =  new wxFileDialog(this, wxT("Choose a file"), wxT(""), wxT(""), wxT("*.*"), wxOPEN | wxFILE_MUST_EXIST);
 
 	WxMenuBar1 = new wxMenuBar();
@@ -83,6 +81,8 @@ void MainFrm::CreateGUIControls()
 	WxMenuBar1->Append(ID_MNU_HELP_1004_Mnu_Obj, wxT("Help"));
 	SetMenuBar(WxMenuBar1);
 
+	WxSaveFileDialog1 =  new wxFileDialog(this, wxT("Choose a file"), wxT(""), wxT(""), wxT("*.*"), wxSAVE | wxOVERWRITE_PROMPT);
+
 	SetStatusBar(WxStatusBar1);
 	SetTitle(wxT("gui"));
 	SetIcon(wxNullIcon);
@@ -201,7 +201,7 @@ void MainFrm::Mnuviewmmsfile1008Click(wxCommandEvent& event)
     MMSFrm              *subframe;
     char                buff[5000];
     GSM_File            *File;
-	GSM_MMSDecodedFile  *Decoded;    
+	GSM_SMSMMSDecodedEntry  *Decoded;    
 	GSM_Error           error;
 
     WxOpenFileDialog1->SetMessage("Please select MMS file for open");
@@ -212,8 +212,8 @@ void MainFrm::Mnuviewmmsfile1008Click(wxCommandEvent& event)
     File = new GSM_File;
     File->ReadFromDisk(StringToUnicodeReturn((char *)WxOpenFileDialog1->GetPath().c_str()));
     
-    Decoded = new GSM_MMSDecodedFile;
-    error = Decoded->Read(File);
+    Decoded = new GSM_SMSMMSDecodedEntry;
+    error = Decoded->ReadFromMMS(File);
     if (PrintError(error)) {
         delete File;
         delete Decoded;
