@@ -13,7 +13,7 @@
 #include "MainFrm.h"
 
 #include "../cfg/config.h"
-#include "../common/service/gsmdata.h"
+#include "../common/service/smsmms/gsmmsg.h"
 #include "../common/service/gsmmisc.h"
 #include "../common/service/backup/gsmback.h"
 #include "../common/gsmstate.h"
@@ -139,6 +139,7 @@ class PhoneFrm : public wxMDIChildFrame
 		wxMediaCtrl *MMSFileWxMediaCtrl;
 		wxTextCtrl *MMSFileWxMemo;
 		wxBoxSizer *WxBoxSizer10;
+		wxListBox *MMSNumbersWxListBox;
 		wxButton *MMSSaveWxButton;
 		wxComboBox *MMFilesWxComboBox;
 		wxPanel *WxPanel11;
@@ -161,8 +162,13 @@ class PhoneFrm : public wxMDIChildFrame
 		wxListCtrl *SMSDetailsWxListCtrl;
 		wxBoxSizer *WxBoxSizer5;
 		wxPanel *WxNoteBookPage2;
-		wxTextCtrl *SMSTextWxMemo;
+		wxTextCtrl *SMSWxMemo;
+		wxMediaCtrl *SMSWxMediaCtrl;
+		wxBoxSizer *WxBoxSizer20;
+		wxButton *SMSSaveWxButton;
+		wxComboBox *SMSFilesWxComboBox;
 		wxListBox *SMSNumbersWxListBox;
+		wxPanel *WxPanel28;
 		wxBoxSizer *WxBoxSizer4;
 		wxPanel *WxNoteBookPage1;
 		wxNotebook *WxNotebook2;
@@ -275,6 +281,7 @@ class PhoneFrm : public wxMDIChildFrame
 			ID_WXNOTEBOOKPAGE4 = 1085,
 			ID_MMSFILEWXMEDIACTRL = 1103,
 			ID_MMSFILEWXMEMO = 1102,
+			ID_MMSNUMBERSWXLISTBOX = 1219,
 			ID_MMSSAVEWXBUTTON = 1101,
 			ID_MMFILESWXCOMBOBOX = 1099,
 			ID_WXPANEL11 = 1098,
@@ -292,8 +299,12 @@ class PhoneFrm : public wxMDIChildFrame
 			ID_MMSWXNOTEBOOKPAGE = 1070,
 			ID_SMSDETAILSWXLISTCTRL = 1065,
 			ID_WXNOTEBOOKPAGE2 = 1063,
-			ID_SMSTEXTWXMEMO = 1081,
-			ID_SMSNUMBERSWXLISTBOX = 1080,
+			ID_SMSWXMEMO = 1226,
+			ID_SMSWXMEDIACTRL = 1225,
+			ID_SMSSAVEWXBUTTON = 1223,
+			ID_SMSFILESWXCOMBOBOX = 1222,
+			ID_SMSNUMBERSWXLISTBOX = 1221,
+			ID_WXPANEL28 = 1220,
 			ID_WXNOTEBOOKPAGE1 = 1059,
 			ID_WXNOTEBOOK2 = 1058,
 			ID_WXPANEL7 = 1067,
@@ -391,6 +402,9 @@ class PhoneFrm : public wxMDIChildFrame
 	    
 public:
         void GetOnlineInfo();        
+		void SMSFilesWxComboBoxSelected(wxCommandEvent& event );
+		void SMSWxMediaCtrlMediaLoaded(wxMediaEvent& event);
+		void SMSSaveWxButtonClick(wxCommandEvent& event);
 private:
         GSM_StateMachine                    *s;
         GSM_Backup                          *Backup;
@@ -421,7 +435,7 @@ private:
         bool                                FirstSMS;
         bool                                FirstMMS;
         unsignedint                         ReadSMSMMS;
-        GSM_MMSDecodedFile                  Decoded;
+        GSM_SMSMMSDecodedEntry              Decoded;
         
         //calendar
         bool                                FirstCalendar;
