@@ -1,12 +1,13 @@
 
 #include "../cfg/config.h"
-#include "../common/service/gsmdata.h"
+#include "../common/service/smsmms/gsmmsg.h"
 #include "../common/service/gsmmisc.h"
 #include "../common/service/backup/gsmback.h"
 #include "../common/gsmstate.h"
 
 #include <wx/msgdlg.h>
 #include <wx/listctrl.h>
+#include <wx/listbox.h>
 #include <wx/combobox.h>
 #include <wx/mediactrl.h>
 #include <wx/textctrl.h>
@@ -94,146 +95,165 @@ void PrintDT(GSM_DateTime *DT, char *Buffer)
     }
 }
 
-int ViewMMSFile(GSM_File *File, GSM_MMSDecodedFile *Decoded, wxListCtrl *List, wxComboBox *FilesList)
+int ViewMMSFile(GSM_File *File, GSM_SMSMMSDecodedEntry *Decoded, wxListCtrl *List, wxComboBox *FilesList, wxListBox *NumbersList, wxBoxSizer *Sizer, wxPanel *Panel)
 {
-	GSM_MMSDecodedFileSubEntry  *SubDecoded;
+	GSM_SMSMMSDecodedSubEntry  *SubDecoded;
 	GSM_Error                   error;
-    long                        tmp,EntryNum=0;
+    long                        tmp,EntryNum=0,NumbersNum=0;
     wchar_t                     Buffer[200];
 	char                        buff[200];
-    BOOLEAN                     Found;
+    BOOLEAN                     Found,AddNum;
     wchart                      Name;
     int                         FileNum=-1,FileNum2=1;
     char                        X[1000];
 
-    List->DeleteAllItems();
+    if (List!=NULL) List->DeleteAllItems();
     FilesList->Clear();
 
-    if (UnicodeLength(File->Info.ID.data())!=0) {
-        tmp = List->InsertItem(EntryNum++, "ID", 0);
-        List->SetItem(tmp, 1, File->Info.ID.data());
+    if (File != NULL) {
+        if (UnicodeLength(File->Info.ID.data())!=0 && List!=NULL) {
+            tmp = List->InsertItem(EntryNum++, "ID", 0);
+            List->SetItem(tmp, 1, File->Info.ID.data());
+        }
     }
 
+    NumbersList->Clear();
+    
     SubDecoded = NULL;
     while (Decoded->GetNext(&SubDecoded)) {
         Found = false;
+        AddNum=false;
         switch (SubDecoded->Type) {
         case MMS_Address_Phone_Source:
-            tmp = List->InsertItem(EntryNum++, "From (phone)", 0); Found = true;
+            if (List != NULL) tmp = List->InsertItem(EntryNum++, "From (phone)", 0); Found = true;
+            AddNum = true;
             break;
     	case MMS_Address_Unknown_Source:
-            tmp = List->InsertItem(EntryNum++, "From", 0); Found = true;
+            if (List != NULL) tmp = List->InsertItem(EntryNum++, "From", 0); Found = true;
+            AddNum = true;
             break;
         case MMS_Address_Phone_Destination:
-            tmp = List->InsertItem(EntryNum++, "To (phone)", 0); Found = true;
+            if (List != NULL) tmp = List->InsertItem(EntryNum++, "To (phone)", 0); Found = true;
             break;
         case MMS_Address_Unknown_Destination:
-            tmp = List->InsertItem(EntryNum++, "To", 0); Found = true;
+            if (List != NULL) tmp = List->InsertItem(EntryNum++, "To", 0); Found = true;
             break;
         case MMS_Address_Phone_CC:
-            tmp = List->InsertItem(EntryNum++, "CC (phone)", 0); Found = true;
+            if (List != NULL) tmp = List->InsertItem(EntryNum++, "CC (phone)", 0); Found = true;
             break;
         case MMS_Address_Unknown_CC:
-            tmp = List->InsertItem(EntryNum++, "CC", 0); Found = true;
+            if (List != NULL) tmp = List->InsertItem(EntryNum++, "CC", 0); Found = true;
             break;
         case MMS_Address_Phone_BCC:
-            tmp = List->InsertItem(EntryNum++, "BCC (phone)", 0); Found = true;
+            if (List != NULL) tmp = List->InsertItem(EntryNum++, "BCC (phone)", 0); Found = true;
             break;
         case MMS_Address_Unknown_BCC:
-            tmp = List->InsertItem(EntryNum++, "BCC", 0); Found = true;
+            if (List != NULL) tmp = List->InsertItem(EntryNum++, "BCC", 0); Found = true;
             break;
         case MMS_Unknown:
-            tmp = List->InsertItem(EntryNum++, "<Unknown content>", 0); Found = true;
+            if (List != NULL) tmp = List->InsertItem(EntryNum++, "<Unknown content>", 0); Found = true;
             break;
         }
         if (Found) {
             memcpy(Buffer,SubDecoded->Text.data(),(SubDecoded->Text.length()+1)*sizeof(wchar_t));
 //            FindSMSNumber(Buffer);
-            List->SetItem(tmp, 1, Buffer);
-            continue;
-        }
-        switch (SubDecoded->Type) {
-        case MMS_Text_TransactionID:
-            tmp = List->InsertItem(EntryNum++, "Transaction ID", 0); Found = TRUE;
-            break;
-        case MMS_Text_Subject:
-            tmp = List->InsertItem(EntryNum++, "Subject", 0); Found = TRUE;
-            break;
-        case MMS_Text_ContentLocation:
-            tmp = List->InsertItem(EntryNum++, "Content location", 0); Found = TRUE;
-            break;
-        case MMS_Text_ContentType:
-            tmp = List->InsertItem(EntryNum++, "Content type", 0); Found = TRUE;
-            break;
-        case MMS_Text_MessageType:
-            tmp = List->InsertItem(EntryNum++, "Message type", 0); Found = TRUE;
-            break;
-        case MMS_Text_MessageID:
-            tmp = List->InsertItem(EntryNum++, "Message ID", 0); Found = TRUE;
-            break;
-        case MMS_Text_MessageClass:
-            tmp = List->InsertItem(EntryNum++, "Message class", 0); Found = TRUE;
-            break;
-        case MMS_Text_Priority:
-            tmp = List->InsertItem(EntryNum++, "Priority", 0); Found = TRUE;
-            break;
-        case MMS_Text_Version:
-            tmp = List->InsertItem(EntryNum++, "MMS version", 0); Found = TRUE;
-            break;
-        case MMS_Text_Response_Status:
-            tmp = List->InsertItem(EntryNum++, "Response status", 0); Found = TRUE;
-            break;
-        case MMS_Text_Status:
-            tmp = List->InsertItem(EntryNum++, "Status", 0); Found = TRUE;
-            break;
-        }
-        if (Found) {
-            List->SetItem(tmp, 1, SubDecoded->Text.data());
-            continue;
-        }
-        switch (SubDecoded->Type) {
-        case MMS_Bool_Report:
-            tmp = List->InsertItem(EntryNum++, "Delivery report", 0); Found = TRUE;
-            break;
-        case MMS_Bool_Read_Reply:
-            tmp = List->InsertItem(EntryNum++, "Read reply", 0); Found = TRUE;
-            break;
-        case MMS_Bool_Report_Allowed:
-            tmp = List->InsertItem(EntryNum++, "Report allowed", 0); Found = TRUE;
-            break;
-        }
-        if (Found) {
-            if (SubDecoded->Bool) {
-                List->SetItem(tmp, 1, "yes");
-            } else {
-                List->SetItem(tmp, 1, "no");
+            if (List != NULL) List->SetItem(tmp, 1, Buffer);
+            if (AddNum) {
+                NumbersList->Append(Buffer);
+                NumbersNum++;
             }
             continue;
         }
+        if (List!=NULL) {
+            switch (SubDecoded->Type) {
+            case MMS_Text_TransactionID:
+                tmp = List->InsertItem(EntryNum++, "Transaction ID", 0); Found = TRUE;
+                break;
+            case MMS_Text_Subject:
+                tmp = List->InsertItem(EntryNum++, "Subject", 0); Found = TRUE;
+                break;
+            case MMS_Text_ContentLocation:
+                tmp = List->InsertItem(EntryNum++, "Content location", 0); Found = TRUE;
+                break;
+            case MMS_Text_ContentType:
+                tmp = List->InsertItem(EntryNum++, "Content type", 0); Found = TRUE;
+                break;
+            case MMS_Text_MessageType:
+                tmp = List->InsertItem(EntryNum++, "Message type", 0); Found = TRUE;
+                break;
+            case MMS_Text_MessageID:
+                tmp = List->InsertItem(EntryNum++, "Message ID", 0); Found = TRUE;
+                break;
+            case MMS_Text_MessageClass:
+                tmp = List->InsertItem(EntryNum++, "Message class", 0); Found = TRUE;
+                break;
+            case MMS_Text_Priority:
+                tmp = List->InsertItem(EntryNum++, "Priority", 0); Found = TRUE;
+                break;
+            case MMS_Text_Version:
+                tmp = List->InsertItem(EntryNum++, "MMS version", 0); Found = TRUE;
+                break;
+            case MMS_Text_Response_Status:
+                tmp = List->InsertItem(EntryNum++, "Response status", 0); Found = TRUE;
+                break;
+            case MMS_Text_Status:
+                tmp = List->InsertItem(EntryNum++, "Status", 0); Found = TRUE;
+                break;
+            }
+            if (Found) {
+                List->SetItem(tmp, 1, SubDecoded->Text.data());
+                continue;
+            }
+            switch (SubDecoded->Type) {
+            case MMS_Bool_Report:
+                tmp = List->InsertItem(EntryNum++, "Delivery report", 0); Found = TRUE;
+                break;
+            case MMS_Bool_Read_Reply:
+                tmp = List->InsertItem(EntryNum++, "Read reply", 0); Found = TRUE;
+                break;
+            case MMS_Bool_Report_Allowed:
+                tmp = List->InsertItem(EntryNum++, "Report allowed", 0); Found = TRUE;
+                break;
+            }
+            if (Found) {
+                if (SubDecoded->Bool) {
+                    List->SetItem(tmp, 1, "yes");
+                } else {
+                    List->SetItem(tmp, 1, "no");
+                }
+                continue;
+            }
+        }
         switch (SubDecoded->Type) {
         case MMS_DT_DateTime:
-            tmp = List->InsertItem(EntryNum++, "Sent", 0);
-            PrintDT(&SubDecoded->DT, buff);
-            List->SetItem(tmp, 1, buff);
+            if (List!=NULL) {
+                tmp = List->InsertItem(EntryNum++, "Sent", 0);
+                PrintDT(&SubDecoded->DT, buff);
+                List->SetItem(tmp, 1, buff);
+            }
             break;
     	case MMS_DT_Expiry:
-            tmp = List->InsertItem(EntryNum++, "Expiry", 0);
-            List->SetItem(tmp, 1, SubDecoded->Text.data());
+            if (List!=NULL) {
+                tmp = List->InsertItem(EntryNum++, "Expiry", 0);
+                List->SetItem(tmp, 1, SubDecoded->Text.data());
+            }
             break;
         case MMS_File:
-            tmp = List->InsertItem(EntryNum++, "File", 0);
-            tmp = List->InsertItem(EntryNum++, "  Content type", 0);
-            sprintf(X,"%s",UnicodeToStringReturn(SubDecoded->Text.data()));
-            sprintf(X+strlen(X),"%s",UnicodeToStringReturn(SubDecoded->Text2.data()));
-            List->SetItem(tmp, 1, X);            
-
-            if (SubDecoded->Header.length()!=0) {
-                tmp = List->InsertItem(EntryNum++, "  Header", 0);
-                List->SetItem(tmp, 1, SubDecoded->Header.data());
+            if (List!=NULL) {
+                tmp = List->InsertItem(EntryNum++, "File", 0);
+                tmp = List->InsertItem(EntryNum++, "  Content type", 0);
+                sprintf(X,"%s",UnicodeToStringReturn(SubDecoded->Text.data()));
+                sprintf(X+strlen(X),"%s",UnicodeToStringReturn(SubDecoded->Text2.data()));
+                List->SetItem(tmp, 1, X);            
+    
+                if (SubDecoded->Header.length()!=0) {
+                    tmp = List->InsertItem(EntryNum++, "  Header", 0);
+                    List->SetItem(tmp, 1, SubDecoded->Header.data());
+                }
+                tmp = List->InsertItem(EntryNum++, "  Size", 0);
+                sprintf(buff,"%i bytes",SubDecoded->File.Info.Size);
+                List->SetItem(tmp, 1, buff);
             }
-            tmp = List->InsertItem(EntryNum++, "  Size", 0);
-            sprintf(buff,"%i bytes",SubDecoded->File.Info.Size);
-            List->SetItem(tmp, 1, buff);
             
             Name.clear();
             Name.append(SubDecoded->File.Info.Name.data(),UnicodeLength(SubDecoded->File.Info.Name.data()));
@@ -250,19 +270,24 @@ int ViewMMSFile(GSM_File *File, GSM_MMSDecodedFile *Decoded, wxListCtrl *List, w
             break;
         }
     }
+    FilesList->Enable(true);
+    if (FileNum2<3) FilesList->Enable(false);
+    NumbersList->SetSizeHints(500,NumbersNum*15);
+    Panel->SetSizeHints(900,NumbersNum*15+10);
+    Sizer->Layout();    
     return FileNum;
 }
 
-void MMSSelect(int Num, GSM_MMSDecodedFile *Decoded, wxMediaCtrl *MediaCtrl1, wxTextCtrl *Memo1, wxBoxSizer *BoxSizer3, wxButton *Button) 
+void MMSSelect(int Num, GSM_SMSMMSDecodedEntry *Decoded, wxMediaCtrl *MediaCtrl1, wxTextCtrl *Memo1, wxBoxSizer *BoxSizer3, wxButton *Button) 
 {
     BOOLEAN                     wrong;
     int                         num5=0;
     int                         Num2;
     GSM_SMSMMSFoldersSubEntry   *SubFolder;
     GSM_Error                   error,preverror;
-    GSM_MMSFile                 Entry2;
+    GSM_MMSEntry                 Entry2;
     BOOLEAN                     wasmore = false;
-	GSM_MMSDecodedFileSubEntry  *SubDecoded;
+	GSM_SMSMMSDecodedSubEntry  *SubDecoded;
 	BOOLEAN                     found;
 	wxImage                     newImage ;
 	wxBitmap                    *newBitmap;
@@ -345,10 +370,10 @@ void MMSSelect(int Num, GSM_MMSDecodedFile *Decoded, wxMediaCtrl *MediaCtrl1, wx
     }
 }
 
-void SaveMMSFile(GSM_MMSDecodedFile *Decoded, wxFileDialog *WxSaveFileDialog1, int Num)
+void SaveMMSFile(GSM_SMSMMSDecodedEntry *Decoded, wxFileDialog *WxSaveFileDialog1, int Num)
 {
     int                         num5=0;
-	GSM_MMSDecodedFileSubEntry  *SubDecoded;
+	GSM_SMSMMSDecodedSubEntry  *SubDecoded;
 
     SubDecoded = NULL;
     while (Decoded->GetNext(&SubDecoded)) {
