@@ -9,10 +9,11 @@
 #include <wx/image.h>
 #include <wx/button.h>
 #include <wx/filedlg.h>
+#include <wx/sizer.h>
 
 
 #include "../cfg/config.h"
-#include "../common/service/gsmdata.h"
+#include "../common/service/smsmms/gsmmsg.h"
 #include "../common/service/gsmmisc.h"
 #include "../common/service/backup/gsmback.h"
 #include "../common/gsmstate.h"
@@ -20,8 +21,8 @@
 BOOLEAN PrintError (GSM_Error error);
 char *DayOfWeekStr(int Year, int Month, int Day);
 void PrintDT(GSM_DateTime *DT, char *Buffer);
-int ViewMMSFile(GSM_File *File, GSM_MMSDecodedFile *Decoded, wxListCtrl *List, wxComboBox *FilesList);
-void MMSSelect(int Num, GSM_MMSDecodedFile *Decoded, wxMediaCtrl *MediaCtrl1, wxTextCtrl *Memo1, wxBoxSizer *BoxSizer3, wxButton *Button);
-void SaveMMSFile(GSM_MMSDecodedFile *Decoded, wxFileDialog *WxSaveFileDialog1, int Num);
+int ViewMMSFile(GSM_File *File, GSM_SMSMMSDecodedEntry *Decoded, wxListCtrl *List, wxComboBox *FilesList, wxListBox *NumbersList, wxBoxSizer *Sizer, wxPanel *Panel);
+void MMSSelect(int Num, GSM_SMSMMSDecodedEntry *Decoded, wxMediaCtrl *MediaCtrl1, wxTextCtrl *Memo1, wxBoxSizer *BoxSizer3, wxButton *Button);
+void SaveMMSFile(GSM_SMSMMSDecodedEntry *Decoded, wxFileDialog *WxSaveFileDialog1, int Num);
 
 #endif
